@@ -5,23 +5,24 @@
 # Author: Paul McCarthy <pauldmccarthy@gmail.com>
 #
 """This module provides the :class:`OrthoToolBar` class, which is a
-:class:`.FSLeyesToolBar` for use with the :class:`.OrthoPanel`.
+:class:`.ControlToolBar` for use with the :class:`.OrthoPanel`.
 """
 
 
 import wx
 
-import fsleyes_props    as props
-
-import fsleyes.toolbar  as fsltoolbar
-import fsleyes.icons    as fslicons
-import fsleyes.tooltips as fsltooltips
-import fsleyes.actions  as actions
-import fsleyes.strings  as strings
+import fsleyes_props                 as props
+import fsleyes.controls.controlpanel as ctrlpanel
+import fsleyes.views.orthopanel      as orthopanel
+import fsleyes.toolbar               as fsltoolbar
+import fsleyes.icons                 as fslicons
+import fsleyes.tooltips              as fsltooltips
+import fsleyes.actions               as actions
+import fsleyes.strings               as strings
 
 
-class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
-    """The ``OrthoToolBar`` is a :class:`.FSLeyesToolBar` for use with the
+class OrthoToolBar(ctrlpanel.ControlToolBar):
+    """The ``OrthoToolBar`` is a :class:`.ControlToolBar` for use with the
     :class:`.OrthoPanel`. An ``OrthoToolBar`` looks something like this:
 
 
@@ -54,23 +55,31 @@ class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
     """
 
 
-    def __init__(self, parent, overlayList, displayCtx, frame, ortho):
+    @staticmethod
+    def supportedViews():
+        """Overrides :meth:`.ControlMixin.supportedViews`. The
+        ``OrthoToolBar`` is only intended to be added to
+        :class:`.OrthoPanel` views.
+        """
+        return [orthopanel.OrthoPanel]
+
+
+    def __init__(self, parent, overlayList, displayCtx, ortho):
         """Create an ``OrthoToolBar``.
 
         :arg parent:      The :mod:`wx` parent object.
         :arg overlayList: The :class:`.OverlayList` instance.
         :arg displayCtx:  The :class:`.DisplayContext` instance.
-        :arg frame:       The :class:`.FSLeyesFrame` instance.
         :arg ortho:       The :class:`.OrthoPanel` instance.
         """
 
-        fsltoolbar.FSLeyesToolBar.__init__(self,
-                                           parent,
-                                           overlayList,
-                                           displayCtx,
-                                           frame,
-                                           height=24,
-                                           kbFocus=True)
+        ctrlpanel.ControlToolBar.__init__(self,
+                                          parent,
+                                          overlayList,
+                                          displayCtx,
+                                          ortho,
+                                          height=24,
+                                          kbFocus=True)
 
         self.orthoPanel = ortho
 
@@ -80,7 +89,7 @@ class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
         # Profile instance changes too, so we need
         # to re-create these action buttons. I'm being
         # lazy and just re-generating the entire toolbar.
-        ortho.addListener('profile', self.name, self.__makeTools)
+        ortho.events.register(self.name, self.__makeTools, 'profile')
 
         self.addListener('showCursorAndLabels',
                          self.name,
@@ -94,10 +103,10 @@ class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
         Removes some property listeners, and calls the base class
         implementation.
         """
-        self.orthoPanel.removeListener('profile',             self.name)
+        self.orthoPanel.events.deregister(self.name, 'profile')
         self           .removeListener('showCursorAndLabels', self.name)
 
-        fsltoolbar.FSLeyesToolBar.destroy(self)
+        ctrlpanel.ControlToolBar.destroy(self)
 
 
     def __makeTools(self, *a):
@@ -109,7 +118,7 @@ class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
 
         ortho     = self.orthoPanel
         orthoOpts = ortho.sceneOpts
-        profile   = ortho.getCurrentProfile()
+        profile   = ortho.currentProfile
 
         coronalIcon          = 'coronalSlice24'
         coronalHighlightIcon = 'coronalSliceHighlight24'
@@ -132,7 +141,7 @@ class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
             'showZCanvas'      : [
                 fslicons.findImageFile('axialSliceHighlight24'),
                 fslicons.findImageFile('axialSlice24')],
-            'toggleCanvasSettingsPanel' : [
+            'CanvasSettingsPanel' : [
                 fslicons.findImageFile('spannerHighlight24'),
                 fslicons.findImageFile('spanner24')],
 
@@ -159,30 +168,29 @@ class OrthoToolBar(fsltoolbar.FSLeyesToolBar):
             'showXCanvas'  : fsltooltips.properties[orthoOpts, 'showXCanvas'],
             'showYCanvas'  : fsltooltips.properties[orthoOpts, 'showYCanvas'],
             'showZCanvas'  : fsltooltips.properties[orthoOpts, 'showZCanvas'],
-            'toggleCanvasSettingsPanel' : fsltooltips.actions[
-                ortho, 'toggleCanvasSettingsPanel'],
+            'CanvasSettingsPanel' : fsltooltips.actions[ortho,
+                                                        'CanvasSettingsPanel'],
 
         }
 
-        targets    = {'screenshot'                : ortho,
-                      'movieMode'                 : ortho,
-                      'showCursorAndLabels'       : self,
-                      'resetDisplay'              : profile,
-                      'zoom'                      : orthoOpts,
-                      'layout'                    : orthoOpts,
-                      'showXCanvas'               : orthoOpts,
-                      'showYCanvas'               : orthoOpts,
-                      'showZCanvas'               : orthoOpts,
-                      'toggleCanvasSettingsPanel' : ortho}
-
+        targets    = {'screenshot'          : ortho,
+                      'movieMode'           : ortho,
+                      'showCursorAndLabels' : self,
+                      'resetDisplay'        : profile,
+                      'zoom'                : orthoOpts,
+                      'layout'              : orthoOpts,
+                      'showXCanvas'         : orthoOpts,
+                      'showYCanvas'         : orthoOpts,
+                      'showZCanvas'         : orthoOpts,
+                      'CanvasSettingsPanel' : ortho}
 
         toolSpecs = [
 
             actions.ToggleActionButton(
-                'toggleCanvasSettingsPanel',
+                'CanvasSettingsPanel',
                 actionKwargs={'floatPane' : True},
-                icon=icons['toggleCanvasSettingsPanel'],
-                tooltip=tooltips['toggleCanvasSettingsPanel']),
+                icon=icons['CanvasSettingsPanel'],
+                tooltip=tooltips['CanvasSettingsPanel']),
             actions.ActionButton('screenshot',
                                  icon=icons['screenshot'],
                                  tooltip=tooltips['screenshot']),
